#-----------------------------------------------------#
# example.R
#
# Illustrates use of jackknife code 'jregress.R'.
# Implements methods from "Jackknife standard errors for clustered regression"
# by Bruce E. Hansen
#
# This example file uses the pre-processed data file Meng_1.dta, and uses the R package haven to load the data.
#
# Three example regressions are shown. 
#
# The first example calculates the regression output for the model corresponding to the first column of Table 7 of the paper.
#
# The second example adds two cluster-level dummy variable indicators. These variables fail clusterwise invertibility.
# The regression and standard errors are reported, but a warning message is displayed.
# 
# The third example takes the first example, and estimates by fixed effects (within transformation).
# It also uses the df.display option to simplify the output table.
# 
#-----------------------------------------------------#

library(haven)
source('jregress.R')

dat1 <- read_dta("Meng_1.dta")
dat1 <- subset(dat1,dat1$lgrain_pred_famdum5860!='.')
dat1 <- subset(dat1,dat1$year>=1953)
dat1 <- subset(dat1,dat1$year<=1982)
dat1$i.year <- as.factor(dat1$year)
dat1$diff_pred <- dat1$lgrain_pred_famdum5860 - dat1$lgrain_pred
dat1$Beijing <- (dat1$province == "Beijing")
dat1$Tianjin <- (dat1$province == "Tianjin")

cat("\n-------------------------------------------------------------\n")
cat("Example 1\n")
jack <- jregress(ldeath_b~diff_pred+lgrain_pred+ltotpop+lurbpop+i.year, dat1, prov)

cat("\n-------------------------------------------------------------\n")
cat("Example 2\n")
jack <- jregress(ldeath_b~diff_pred+lgrain_pred+ltotpop+lurbpop+i.year+Beijing+Tianjin, dat1, prov)

cat("\n-------------------------------------------------------------\n")
cat("Example 3\n")
jack <- jregress(ldeath_b~diff_pred+lgrain_pred+ltotpop+lurbpop+i.year, dat1, prov, fe=TRUE, df.display=FALSE)